summaryrefslogtreecommitdiff
path: root/vcl/source/glyphs/gcach_ftyp.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'vcl/source/glyphs/gcach_ftyp.hxx')
-rw-r--r--vcl/source/glyphs/gcach_ftyp.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/vcl/source/glyphs/gcach_ftyp.hxx b/vcl/source/glyphs/gcach_ftyp.hxx
index 95f792fa9647..571822375e20 100644
--- a/vcl/source/glyphs/gcach_ftyp.hxx
+++ b/vcl/source/glyphs/gcach_ftyp.hxx
@@ -110,8 +110,8 @@ private:
ImplDevFontAttributes maDevFontAttributes;
// cache unicode->glyphid mapping because looking it up is expensive
- // TODO: change to hash_multimap when a use case requires a m:n mapping
- typedef ::std::hash_map<int,int> Int2IntMap;
+ // TODO: change to boost::unordered_multimap when a use case requires a m:n mapping
+ typedef ::boost::unordered_map<int,int> Int2IntMap;
mutable Int2IntMap* mpChar2Glyph;
mutable Int2IntMap* mpGlyph2Char;
void InitHashes() const;
@@ -157,7 +157,7 @@ public:
FreetypeServerFont* CreateFont( const ImplFontSelectData& );
private:
- typedef ::std::hash_map<sal_IntPtr,FtFontInfo*> FontList;
+ typedef ::boost::unordered_map<sal_IntPtr,FtFontInfo*> FontList;
FontList maFontList;
sal_IntPtr mnMaxFontId;
@@ -224,7 +224,7 @@ private:
bool mbArtBold;
bool mbUseGamma;
- typedef ::std::hash_map<int,int> GlyphSubstitution;
+ typedef ::boost::unordered_map<int,int> GlyphSubstitution;
GlyphSubstitution maGlyphSubstitution;
rtl_UnicodeToTextConverter maRecodeConverter;